<!-- markdownlint-disable -->



# <kbd>module</kbd> `helper`






---



## <kbd>class</kbd> `SdkHelper`






### <kbd>method</kbd> `__init__`

```python
__init__() → None
```








---



### <kbd>method</kbd> `get_platform_base_url`

```python
get_platform_base_url(platform_host: str, platform_port: str) → str
```

Make base url from host and port. 



**Args:**
 
 - <b>`platform_host`</b> (str):  Host of platform service 
 - <b>`platform_port`</b> (str):  Port of platform service 



**Returns:**
 
 - <b>`str`</b>:  URL to the platform service 




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
